@@ -1,10 +1,10 @@
 //! Various assertions.
 
-/// Runs a block, returning a [anchor_lang::prelude::ProgramResult].
+/// Runs a block, returning a [anchor_lang::prelude::Result<()>].
 #[macro_export]
 macro_rules! test_assertion {
     ($body: block) => {
-        (|| -> ProgramResult {
+        (|| -> crate::Result<()> {
             $body
             Ok(())
         })()
@@ -17,7 +17,7 @@ macro_rules! test_assertion {
 #[macro_export]
 macro_rules! assert_does_not_throw {
     ($body: block $(,)?) => {
-        assert_eq!($crate::test_assertion!($body), Ok(()))
+        assert!($crate::test_assertion!($body).is_ok())
     };
 }
 
@@ -27,7 +27,10 @@ macro_rules! assert_does_not_throw {
 #[macro_export]
 macro_rules! assert_throws {
     ($body: block, $right: expr $(,)?) => {
-        assert_eq!($crate::test_assertion!($body), Err($right.into()))
+        assert_eq!(
+            $crate::IntoCmpError::into_cmp_error($crate::test_assertion!($body).err()),
+            $crate::IntoCmpError::into_cmp_error(Some(::anchor_lang::prelude::error!($right)))
+        )
     };
 }
 
@@ -37,12 +40,12 @@ macro_rules! assert_throws {
 ///
 /// ```
 /// # use anchor_lang::prelude::*;
-/// #[error]
+/// #[error_code]
 /// pub enum ErrorCode {
 ///   #[msg("This is my error")]
 ///   MyError
 /// }
-/// # #[macro_use] extern crate vipers; fn main() -> ProgramResult {
+/// # #[macro_use] extern crate vipers; fn main() -> Result<()> {
 /// assert_eq!(format_err!(ErrorCode::MyError), "MyError: This is my error");
 /// # Ok(())
 /// # }
@@ -60,9 +63,9 @@ macro_rules! format_err {
 ///
 /// ```
 /// # use anchor_lang::prelude::*;
-/// # #[error]
+/// # #[error_code]
 /// # pub enum ErrorCode { MyError }
-/// # #[macro_use] extern crate vipers; fn main() -> ProgramResult {
+/// # #[macro_use] extern crate vipers; fn main() -> Result<()> {
 /// let fail = false;
 /// if fail {
 ///     return program_err!(MyError);
@@ -93,7 +96,7 @@ macro_rules! log_code_location {
 ///
 /// ```
 /// # use anchor_lang::prelude::*;
-/// # #[macro_use] extern crate vipers; fn main() -> ProgramResult {
+/// # #[macro_use] extern crate vipers; fn main() -> Result<()> {
 /// let result = unwrap_opt_block!({
 ///     let one: u64 = 1;
 ///     let three: u64 = 3;
@@ -119,7 +122,7 @@ macro_rules! unwrap_opt_block {
 ///
 /// ```
 /// # use anchor_lang::prelude::*;
-/// # #[macro_use] extern crate vipers; fn main() -> ProgramResult {
+/// # #[macro_use] extern crate vipers; fn main() -> Result<()> {
 /// let result = unwrap_checked!({
 ///   let one: u64 = 1;
 ///   let three: u64 = 3;
@@ -142,9 +145,9 @@ macro_rules! unwrap_checked {
 ///
 /// ```
 /// # use anchor_lang::prelude::*;
-/// # #[error]
+/// # #[error_code]
 /// # pub enum ErrorCode { MyError }
-/// # #[macro_use] extern crate vipers; fn main() -> ProgramResult {
+/// # #[macro_use] extern crate vipers; fn main() -> Result<()> {
 /// let fail = false;
 /// if fail {
 ///     throw_err!(MyError);
@@ -159,7 +162,7 @@ macro_rules! throw_err {
     };
     ($error:expr $(,)?) => {
         $crate::log_code_location!();
-        return Err($error.into());
+        return Err(::anchor_lang::prelude::error!($error));
     };
 }
 
@@ -167,6 +170,7 @@ macro_rules! throw_err {
 ///
 /// Warning: this uses a lot of compute units due to the need to generate a PDA.
 /// It is recommended to cache this value.
+#[cfg(feature = "spl-associated-token-account")]
 #[macro_export]
 #[deprecated(
     since = "1.5.6",
@@ -268,9 +272,9 @@ macro_rules! assert_owner {
 ///
 /// ```should_panic
 /// # use anchor_lang::prelude::*;
-/// # #[error]
+/// # #[error_code]
 /// # pub enum ErrorCode { MyError }
-/// # #[macro_use] extern crate vipers; fn main() -> ProgramResult {
+/// # #[macro_use] extern crate vipers; fn main() -> Result<()> {
 /// let one = anchor_lang::solana_program::sysvar::clock::ID;
 /// let two = anchor_lang::solana_program::system_program::ID;
 /// assert_keys_eq!(one, two); // throws an error
@@ -280,9 +284,9 @@ macro_rules! assert_owner {
 ///
 /// ```should_panic
 /// # use anchor_lang::prelude::*;
-/// # #[error]
+/// # #[error_code]
 /// # pub enum ErrorCode { MyError }
-/// # #[macro_use] extern crate vipers; fn main() -> ProgramResult {
+/// # #[macro_use] extern crate vipers; fn main() -> Result<()> {
 /// let one = anchor_lang::solana_program::sysvar::clock::ID;
 /// let two = anchor_lang::solana_program::system_program::ID;
 /// assert_keys_eq!(one, two, "invalid"); // throws an error
@@ -339,7 +343,7 @@ macro_rules! assert_keys_eq {
 /// # #[macro_use] extern crate vipers;
 /// # use anchor_lang::prelude::*;
 /// # use anchor_spl::token::*;
-/// #[error]
+/// #[error_code]
 /// pub enum ErrorCode { MyError }
 ///
 /// # fn main() {
@@ -408,7 +412,7 @@ macro_rules! assert_is_zero_token_account {
 /// # use anchor_lang::prelude::*;
 /// # impl From<ErrorCode> for ProgramError { fn from(code: ErrorCode) -> Self { ProgramError::Custom(10) } }
 /// # pub enum ErrorCode { MyError }
-/// # #[macro_use] extern crate vipers; fn main() -> ProgramResult {
+/// # #[macro_use] extern crate vipers; fn main() -> Result<()> {
 /// let one = Pubkey::default();
 /// let two = Pubkey::default();
 /// assert_keys_neq!(one, two); // throws an error
@@ -461,7 +465,7 @@ macro_rules! assert_keys_neq {
 /// # use anchor_lang::prelude::*;
 /// # impl From<ErrorCode> for ProgramError { fn from(code: ErrorCode) -> Self { ProgramError::Custom(10) } }
 /// # pub enum ErrorCode { MyError }
-/// # #[macro_use] extern crate vipers; fn main() -> ProgramResult {
+/// # #[macro_use] extern crate vipers; fn main() -> Result<()> {
 /// let one = 1_u64;
 /// let two = 2_u64;
 /// let my_value = unwrap_or_err!(one.checked_sub(2), MyError); // throws an error
@@ -481,7 +485,7 @@ macro_rules! unwrap_or_err {
 ///
 /// ```should_panic
 /// # use anchor_lang::prelude::*;
-/// # #[macro_use] extern crate vipers; fn main() -> ProgramResult {
+/// # #[macro_use] extern crate vipers; fn main() -> Result<()> {
 /// let one = 1_u64;
 /// let two = 2_u64;
 /// let my_value = unwrap_int!(one.checked_sub(2)); // returns an error
@@ -501,11 +505,11 @@ macro_rules! unwrap_int {
 ///
 /// ```should_panic
 /// # use anchor_lang::prelude::*;
-/// # impl From<ErrorCode> for ProgramError { fn from(code: ErrorCode) -> Self { ProgramError::Custom(10) } }
+/// # #[error_code]
 /// # pub enum ErrorCode { MyError }
-/// # #[macro_use] extern crate vipers; fn main() -> ProgramResult {
-/// fn function_returning_result() -> Result<u64, u64> {
-///     Err(123)
+/// # #[macro_use] extern crate vipers; fn main() -> Result<()> {
+/// fn function_returning_result() -> Result<u64> {
+///     err!(ErrorCode::MyError)
 /// }
 ///
 /// let my_value = try_or_err!(function_returning_result(), MyError);
@@ -514,7 +518,7 @@ macro_rules! unwrap_int {
 #[macro_export]
 macro_rules! try_or_err {
     ($result:expr, $error:ident $(,)?) => {
-        $result.map_err(|_| -> ProgramError { crate::ErrorCode::$error.into() })?
+        $result.or_else(|_| -> ::anchor_lang::Result<_> { ::anchor_lang::prelude::err!($error) })?
     };
 }
 
@@ -525,7 +529,7 @@ macro_rules! try_or_err {
 ///
 /// ```should_panic
 /// # use anchor_lang::prelude::*;
-/// # #[macro_use] extern crate vipers; fn main() -> ProgramResult {
+/// # #[macro_use] extern crate vipers; fn main() -> Result<()> {
 /// invariant!(1 == 2, "incorrect");
 /// # Ok(()) }
 /// ```
@@ -534,7 +538,7 @@ macro_rules! try_or_err {
 ///
 /// ```
 /// # use anchor_lang::prelude::*;
-/// # #[macro_use] extern crate vipers; fn main() -> ProgramResult {
+/// # #[macro_use] extern crate vipers; fn main() -> Result<()> {
 /// invariant!(1 == 1, "won't throw");
 /// # Ok(()) }
 /// ```
@@ -543,7 +547,7 @@ macro_rules! try_or_err {
 ///
 /// ```
 /// # use anchor_lang::prelude::*;
-/// # #[macro_use] extern crate vipers; fn main() -> ProgramResult {
+/// # #[macro_use] extern crate vipers; fn main() -> Result<()> {
 /// invariant!(1 == 1);
 /// # Ok(()) }
 /// ```
@@ -553,7 +557,7 @@ macro_rules! try_or_err {
 /// ```
 /// # #[macro_use] extern crate vipers;
 /// # use anchor_lang::prelude::*;
-/// #[error]
+/// #[error_code]
 /// pub enum ErrorCode { MyError }
 ///
 /// # fn main() {
@@ -613,7 +617,7 @@ macro_rules! invariant {
 ///
 /// ```should_panic
 /// # use anchor_lang::prelude::*;
-/// # #[macro_use] extern crate vipers; fn main() -> ProgramResult {
+/// # #[macro_use] extern crate vipers; fn main() -> Result<()> {
 /// let one = 1_u64;
 /// let two = 2_u64;
 /// let my_value = unwrap_opt!(one.checked_sub(2), "cannot do this"); // returns an error
@@ -638,11 +642,11 @@ macro_rules! unwrap_opt {
         $crate::unwrap_opt!($option, $err, $crate::format_err!($err))
     };
     ($option:expr, $err:expr, $msg: expr $(,)?) => {
-        $option.ok_or_else(|| -> ProgramError {
+        $option.ok_or_else(|| -> anchor_lang::error::Error {
             msg!("Option unwrap failed: {:?}", $err);
             msg!(stringify!($option));
             $crate::log_code_location!();
-            $err.into()
+            anchor_lang::prelude::error!($err)
         })?
     };
 }
